<template>
  <div
    element-loading-text="数据加载中..."
    element-loading-spinner="el-icon-loading"
    element-loading-background="rgba(255,255,255, 0.5)"
    v-loading.fullscreen.lock="loading"
  >
    <el-dialog
      v-dialogDrag
      :title="type + '个人黑名单'"
      :visible="visible"
      :before-close="handleClose"
      :close-on-click-modal="false"
      v-if="visible"
      width="60%"
      top="6vh"
      :class="[loading ? 'dialog-box' : '']"
    >
      <div class="dialog-content">
        <div class="left-table">
          <el-table
            :data="tableData"
            border
            height="100%"
            style="width: 100%"
            @selection-change="handleSelectionChange"
          >
            <el-table-column type="selection" width="55" align="center"></el-table-column>
            <el-table-column type="index" width="60" label="序号"></el-table-column>
            <el-table-column prop="name" label="姓名"></el-table-column>
            <el-table-column prop="phone" label="联系电话"></el-table-column>
            <el-table-column prop="idcard" label="身份证号码"></el-table-column>
          </el-table>
        </div>
        <div class="center-tool">
          <div class="tool-btn" @click="deleteChecked">删除</div>
          <div class="tool-btn" @click="clearAll">清空</div>
        </div>
        <div class="right-select">
          <div class="header">已选择</div>
          <div class="checkbox-content">
            <el-checkbox
              class="checked-item"
              v-model="item.checked"
              v-for="(item,index) in checkedList"
              :key="index"
            >{{item.name}}</el-checkbox>
          </div>
        </div>
      </div>
      <el-pagination
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParams.page"
        :page-size="queryParams.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
        align="right"
        style="margin:8px 0 0 0"
      ></el-pagination>
      <div
        slot="footer"
        class="dialog-footer"
        :style="loading ? 'position: relative;z-index: -1;' : ''"
      >
        <el-button @click="handleClose">取消</el-button>
        <el-button type="primary" :disabled="!checkedList.length" @click="handleSave" :loading="btnLoading">确定</el-button>
      </div>
    </el-dialog>
  </div>
</template>
        
<script>
import utils from '@/utils.js'
import BlacklistManage from '@/api/FeedbackArchiving/BlacklistManage.js'

export default {
    props: {},
    name: 'PersonalDialog',
    data() {
        return {
            visible: false,
            loading: false,
            type: '新增',
            tableData: [],
            queryParams: {
                page: 1,
                pageSize: 10
            },
            total: 0,
            checkedList: [],
            btnLoading:false
        }
    },
    created() {},
    methods: {
        open(data) {
            this.visible = true
            this.type = '新增'
            this.getTable()
        },
        getTable() {
            BlacklistManage.findNoBlackByPageByMember(
                {
                    querys: [],
                    pageBean: {
                        ...this.queryParams,
                        showTotal: true
                    }
                },
                res => {
                    this.total = res.total
                    // this.tableLoading = false
                    this.tableData = res.rows
                }
            )
        },
        //编辑
        edit(id) {
            this.visible = true
            this.type = '编辑'
        },
        handleClose() {
            this.visible = false
            this.checkedList = []
        },
        //保存
        handleSave() {
            this.loading = true
            let idArr = this.checkedList.map(it => {
                return it.id
            })
            BlacklistManage.blackListAdd(
                {
                    objectId: idArr,
                    type: '1'
                },
                res => {
                    if (res.state) {
                        this.$notify({
                            type: 'success',
                            message: this.type + '成功',
                            duration: 2000
                        })
                        this.handleClose()
                        this.$emit('getData')
                    } else {
                        this.$message.warning(res.message)
                    }
                    this.loading = false
                }
            )
        },
        handleSizeChange(val) {},
        handleCurrentChange(value) {},
        handleSelectionChange(val) {
            this.checkedList = val
            this.checkedList.forEach(it => {
                this.$set(it, 'checked', false)
            })
        },
        // 删除已选择
        deleteChecked() {
            this.checkedList = this.checkedList.filter(it => {
                return !it.checked
            })
        },
        // 清除所有已选择
        clearAll() {
            this.checkedList = []
        }
    }
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-content {
    display: flex;
    height: 400px;
    .left-table {
        width: 60%;
    }
    .center-tool {
        width: 10%;
        display: flex;
        flex-direction: column;
        flex-wrap: wrap;
        align-items: center;
        justify-content: center;
        .tool-btn {
            padding: 3px 14px;
            border-radius: 4px;
            border: 1px solid #f56c6c;
            color: #f56c6c;
            display: flex;
            justify-content: center;
            align-items: center;
            user-select: none;
            cursor: pointer;
            &:nth-last-child(1) {
                margin-top: 5px;
            }
        }
    }
    .right-select {
        width: 30%;
        border: 1px solid #eee;
        padding: 15px;
        // display: flex;
        .checkbox-content {
            box-sizing: border-box;
            height: 100%;
            padding: 5px;
            display: flex;
            flex-direction: column;
            overflow-y: auto;
            .checked-item {
                margin-top: 8px;
            }
        }
    }
}
</style>